@@ -177,7 +177,7 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
     public function testDoesNotPropagateDefaultValuesForUnsupportedColumnTypes(): void
     {
-        if ($this->schemaManager->getDatabasePlatform() instanceof MariaDb1027Platform) {
+        if ($this->connection->getDatabasePlatform() instanceof MariaDb1027Platform) {
             self::markTestSkipped(
                 'MariaDb102Platform supports default values for BLOB and TEXT columns and will propagate values'
             );
@@ -268,7 +268,7 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
     public function testColumnCollation(): void
     {
         $table = new Table('test_collation');
-        $table->addOption('collate', 'latin1_swedish_ci');
+        $table->addOption('collation', 'latin1_swedish_ci');
         $table->addOption('charset', 'latin1');
         $table->addColumn('id', 'integer');
         $table->addColumn('text', 'text');
@@ -303,7 +303,7 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->dropAndCreateTable($table);
 
-        $platform       = $this->schemaManager->getDatabasePlatform();
+        $platform       = $this->connection->getDatabasePlatform();
         $offlineColumns = $table->getColumns();
         $onlineColumns  = $this->schemaManager->listTableColumns($tableName);
 
@@ -406,7 +406,7 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
     public function testColumnDefaultCurrentTimestamp(): void
     {
-        $platform = $this->schemaManager->getDatabasePlatform();
+        $platform = $this->connection->getDatabasePlatform();
 
         $table = new Table('test_column_defaults_current_timestamp');
 
@@ -429,7 +429,7 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
     {
         $table = new Table('test_column_defaults_are_valid');
 
-        $currentTimeStampSql = $this->schemaManager->getDatabasePlatform()->getCurrentTimestampSQL();
+        $currentTimeStampSql = $this->connection->getDatabasePlatform()->getCurrentTimestampSQL();
         $table->addColumn('col_datetime', 'datetime', ['default' => $currentTimeStampSql]);
         $table->addColumn('col_datetime_null', 'datetime', ['notnull' => false, 'default' => null]);
         $table->addColumn('col_int', 'integer', ['default' => 1]);
@@ -471,11 +471,11 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
      */
     public function testColumnDefaultValuesCurrentTimeAndDate(): void
     {
-        if (! $this->schemaManager->getDatabasePlatform() instanceof MariaDb1027Platform) {
+        if (! $this->connection->getDatabasePlatform() instanceof MariaDb1027Platform) {
             self::markTestSkipped('Only relevant for MariaDb102Platform.');
         }
 
-        $platform = $this->schemaManager->getDatabasePlatform();
+        $platform = $this->connection->getDatabasePlatform();
 
         $table = new Table('test_column_defaults_current_time_and_date');
 
