@@ -9,6 +9,7 @@ use Doctrine\DBAL\Schema\AbstractSchemaManager;
 use Doctrine\DBAL\Schema\Comparator;
 use Doctrine\DBAL\Schema\ForeignKeyConstraint;
 use Doctrine\DBAL\Schema\PostgreSQLSchemaManager;
+use Doctrine\DBAL\Schema\Schema;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Schema\TableDiff;
 use Doctrine\DBAL\Schema\View;
@@ -16,6 +17,7 @@ use Doctrine\DBAL\Types\BlobType;
 use Doctrine\DBAL\Types\DecimalType;
 use Doctrine\DBAL\Types\Type;
 use Doctrine\DBAL\Types\Types;
+use Doctrine\Deprecations\PHPUnit\VerifyDeprecations;
 
 use function array_map;
 use function array_merge;
@@ -23,11 +25,12 @@ use function array_pop;
 use function array_unshift;
 use function assert;
 use function count;
-use function preg_match;
 use function strtolower;
 
 class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 {
+    use VerifyDeprecations;
+
     protected function supportsPlatform(AbstractPlatform $platform): bool
     {
         return $platform instanceof PostgreSQLPlatform;
@@ -107,7 +110,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $column  = $tableTo->addColumn('id', 'integer');
         $column->setAutoincrement(true);
 
-        $platform = $this->schemaManager->getDatabasePlatform();
+        $platform = $this->connection->getDatabasePlatform();
         $diff     = $comparatorFactory($this->schemaManager)->diffTable($tableFrom, $tableTo);
         self::assertNotFalse($diff);
 
@@ -140,7 +143,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $tableTo = new Table('autoinc_table_drop');
         $tableTo->addColumn('id', 'integer');
 
-        $platform = $this->schemaManager->getDatabasePlatform();
+        $platform = $this->connection->getDatabasePlatform();
         $diff     = $comparatorFactory($this->schemaManager)->diffTable($tableFrom, $tableTo);
         self::assertNotFalse($diff);
 
@@ -172,8 +175,11 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $this->schemaManager->createTable($nestedRelatedTable);
         $this->schemaManager->createTable($nestedSchemaTable);
 
-        $tables = $this->schemaManager->listTableNames();
-        self::assertContains('nested.schematable', $tables, 'The table should be detected with its non-public schema.');
+        $tableNames = $this->schemaManager->listTableNames();
+        self::assertContains('nested.schematable', $tableNames);
+
+        $tables = $this->schemaManager->listTables();
+        self::assertNotNull($this->findTableByName($tables, 'nested.schematable'));
 
         $nestedSchemaTable = $this->schemaManager->listTableDetails('nested.schematable');
         self::assertTrue($nestedSchemaTable->hasColumn('id'));
@@ -212,37 +218,8 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         );
     }
 
-    public function testFilterSchemaExpression(): void
-    {
-        $testTable = new Table('dbal204_test_prefix');
-        $testTable->addColumn('id', 'integer');
-        $this->dropAndCreateTable($testTable);
-
-        $testTable = new Table('dbal204_without_prefix');
-        $testTable->addColumn('id', 'integer');
-        $this->dropAndCreateTable($testTable);
-
-        $this->markConnectionNotReusable();
-
-        $this->connection->getConfiguration()->setSchemaAssetsFilter(static function (string $name): bool {
-            return preg_match('#^dbal204_#', $name) === 1;
-        });
-        $names = $this->schemaManager->listTableNames();
-        self::assertCount(2, $names);
-
-        $this->connection->getConfiguration()->setSchemaAssetsFilter(static function (string $name): bool {
-            return preg_match('#^dbal204_test#', $name) === 1;
-        });
-        $names = $this->schemaManager->listTableNames();
-        self::assertCount(1, $names);
-    }
-
     public function testListForeignKeys(): void
     {
-        if (! $this->connection->getDatabasePlatform()->supportsForeignKeyConstraints()) {
-            self::markTestSkipped('Does not support foreign key constraints.');
-        }
-
         $fkOptions   = ['SET NULL', 'SET DEFAULT', 'NO ACTION', 'CASCADE', 'RESTRICT'];
         $foreignKeys = [];
         $fkTable     = $this->getTestTable('test_create_fk1');
@@ -328,34 +305,47 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertInstanceOf(BlobType::class, $table->getColumn($columnName)->getType());
     }
 
-    public function testListQuotedTable(): void
+    /**
+     * Although this test would pass in isolation on any platform, we keep it here for the following reasons:
+     *
+     * 1. The DBAL currently doesn't properly drop tables in the namespaces that need to be quoted
+     *    (@see testListTableDetailsWhenCurrentSchemaNameQuoted()).
+     * 2. The schema returned by {@see AbstractSchemaManager::createSchema()} doesn't contain views, so
+     *    {@see AbstractSchemaManager::dropSchemaObjects()} cannot drop the tables that have dependent views
+     *    (@see testListTablesExcludesViews()).
+     * 3. In the case of inheritance, PHPUnit runs the tests declared immediately in the test class
+     *    and then runs the tests declared in the parent.
+     *
+     * This test needs to be executed before the ones it conflicts with, so it has to be declared in the same class.
+     */
+    public function testDropWithAutoincrement(): void
     {
-        $offlineTable = new Table('user');
-        $offlineTable->addColumn('id', 'integer');
-        $offlineTable->addColumn('username', 'string');
-        $offlineTable->addColumn('fk', 'integer');
-        $offlineTable->setPrimaryKey(['id']);
-        $offlineTable->addForeignKeyConstraint($offlineTable, ['fk'], ['id']);
+        $this->dropTableIfExists('test_autoincrement');
 
-        $this->dropAndCreateTable($offlineTable);
+        $schema = new Schema();
+        $table  = $schema->createTable('test_autoincrement');
+        $table->addColumn('id', 'integer', [
+            'notnull' => true,
+            'autoincrement' => true,
+        ]);
+        $table->setPrimaryKey(['id']);
 
-        $onlineTable = $this->schemaManager->listTableDetails('"user"');
+        $schemaManager = $this->connection->createSchemaManager();
+        $schemaManager->createSchemaObjects($schema);
 
-        $comparator = new Comparator();
+        $schema = $schemaManager->createSchema();
+        $schemaManager->dropSchemaObjects($schema);
 
-        self::assertFalse($comparator->diffTable($offlineTable, $onlineTable));
+        self::assertFalse($schemaManager->tablesExist(['test_autoincrement']));
     }
 
     public function testListTableDetailsWhenCurrentSchemaNameQuoted(): void
     {
         $this->connection->executeStatement('CREATE SCHEMA "001_test"');
         $this->connection->executeStatement('SET search_path TO "001_test"');
+        $this->markConnectionNotReusable();
 
-        try {
-            $this->testListQuotedTable();
-        } finally {
-            $this->connection->close();
-        }
+        $this->testIntrospectReservedKeywordTableViaListTableDetails();
     }
 
     public function testListTablesExcludesViews(): void
@@ -416,6 +406,38 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertTrue(true, $columns['foo']->getPlatformOption('jsonb'));
     }
 
+    public function testItTriggersADeprecationWhenAttemptingToUseJsonbWithATypeNotExtendingJsonType(): void
+    {
+        $backedUpType = Type::getType('json');
+        try {
+            Type::getTypeRegistry()->override(Types::JSON, new class extends Type {
+                /**
+                 * {@inheritdoc}
+                 */
+                public function getSQLDeclaration(array $column, AbstractPlatform $platform): string
+                {
+                    return $platform->getJsonTypeDeclarationSQL($column);
+                }
+
+                public function getName(): string
+                {
+                    return 'json';
+                }
+            });
+            $table = new Table('test_jsonb');
+            $table->addColumn('foo', Types::JSON)->setPlatformOption('jsonb', true);
+            $this->dropAndCreateTable($table);
+
+            $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/5049');
+            $columns = $this->schemaManager->listTableColumns('test_jsonb');
+
+            self::assertSame(Types::JSON, $columns['foo']->getType()->getName());
+            self::assertTrue(true, $columns['foo']->getPlatformOption('jsonb'));
+        } finally {
+            Type::getTypeRegistry()->override(Types::JSON, $backedUpType);
+        }
+    }
+
     public function testListNegativeColumnDefaultValue(): void
     {
         $table = new Table('test_default_negative');
