@@ -18,6 +18,7 @@ use Doctrine\DBAL\Schema\ColumnDiff;
 use Doctrine\DBAL\Schema\Comparator;
 use Doctrine\DBAL\Schema\ForeignKeyConstraint;
 use Doctrine\DBAL\Schema\Index;
+use Doctrine\DBAL\Schema\Schema;
 use Doctrine\DBAL\Schema\SchemaDiff;
 use Doctrine\DBAL\Schema\Sequence;
 use Doctrine\DBAL\Schema\Table;
@@ -55,8 +56,7 @@ use function substr;
 
 abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 {
-    /** @var AbstractSchemaManager */
-    protected $schemaManager;
+    protected AbstractSchemaManager $schemaManager;
 
     abstract protected function supportsPlatform(AbstractPlatform $platform): bool;
 
@@ -73,7 +73,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
     protected function tearDown(): void
     {
-        if ($this->schemaManager === null) {
+        if (! isset($this->schemaManager)) {
             return;
         }
 
@@ -153,7 +153,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
     public function testListDatabases(): void
     {
-        if (! $this->schemaManager->getDatabasePlatform()->supportsCreateDropDatabase()) {
+        if (! $this->connection->getDatabasePlatform()->supportsCreateDropDatabase()) {
             self::markTestSkipped('Cannot drop Database client side with this Driver.');
         }
 
@@ -219,21 +219,55 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         $this->createTestTable('list_tables_test');
         $tables = $this->schemaManager->listTables();
 
-        $foundTable = false;
-        foreach ($tables as $table) {
-            self::assertInstanceOf(Table::class, $table);
-            if (strtolower($table->getName()) !== 'list_tables_test') {
-                continue;
+        $table = $this->findTableByName($tables, 'list_tables_test');
+        self::assertNotNull($table);
+
+        self::assertTrue($table->hasColumn('id'));
+        self::assertTrue($table->hasColumn('test'));
+        self::assertTrue($table->hasColumn('foreign_key_test'));
+    }
+
+    public function testListTablesDoesNotIncludeViews(): void
+    {
+        $this->createTestTable('test_table_for_view');
+
+        $sql = 'SELECT * FROM test_table_for_view';
+
+        $view = new View('test_view', $sql);
+        $this->schemaManager->createView($view);
+
+        $tables = $this->schemaManager->listTables();
+        $view   = $this->findTableByName($tables, 'test_view');
+        self::assertNull($view);
+    }
+
+    /**
+     * @dataProvider tableFilterProvider
+     */
+    public function testListTablesWithFilter(string $prefix, int $expectedCount): void
+    {
+        $this->createTestTable('filter_test_1');
+        $this->createTestTable('filter_test_2');
+
+        $this->markConnectionNotReusable();
+
+        $this->connection->getConfiguration()->setSchemaAssetsFilter(
+            static function (string $name) use ($prefix): bool {
+                return substr(strtolower($name), 0, strlen($prefix)) === $prefix;
             }
+        );
 
-            $foundTable = true;
+        self::assertCount($expectedCount, $this->schemaManager->listTableNames());
+        self::assertCount($expectedCount, $this->schemaManager->listTables());
+    }
 
-            self::assertTrue($table->hasColumn('id'));
-            self::assertTrue($table->hasColumn('test'));
-            self::assertTrue($table->hasColumn('foreign_key_test'));
-        }
-
-        self::assertTrue($foundTable, "The 'list_tables_test' table has to be found.");
+    /**
+     * @return iterable<string, array{string, int}>
+     */
+    public static function tableFilterProvider(): iterable
+    {
+        yield 'One table' => ['filter_test_1', 1];
+        yield 'Two tables' => ['filter_test_', 2];
     }
 
     public function createListTableColumns(): Table
@@ -353,7 +387,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         $eventManager = new EventManager();
         $eventManager->addEventListener([Events::onSchemaColumnDefinition], $listenerMock);
 
-        $this->schemaManager->getDatabasePlatform()->setEventManager($eventManager);
+        $this->connection->getDatabasePlatform()->setEventManager($eventManager);
 
         $this->schemaManager->listTableColumns('list_table_columns');
     }
@@ -374,7 +408,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         $eventManager = new EventManager();
         $eventManager->addEventListener([Events::onSchemaIndexDefinition], $listenerMock);
 
-        $this->schemaManager->getDatabasePlatform()->setEventManager($eventManager);
+        $this->connection->getDatabasePlatform()->setEventManager($eventManager);
 
         $this->schemaManager->listTableIndexes('list_table_indexes_test');
     }
@@ -408,7 +442,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
      */
     public function testDiffListTableColumns(callable $comparatorFactory): void
     {
-        if ($this->schemaManager->getDatabasePlatform() instanceof OraclePlatform) {
+        if ($this->connection->getDatabasePlatform() instanceof OraclePlatform) {
             self::markTestSkipped(
                 'Does not work with Oracle, since it cannot detect DateTime, Date and Time differences (at the moment).'
             );
@@ -433,7 +467,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
         $tableIndexes = $this->schemaManager->listTableIndexes('list_table_indexes_test');
 
-        self::assertEquals(3, count($tableIndexes));
+        self::assertCount(3, $tableIndexes);
 
         self::assertArrayHasKey('primary', $tableIndexes, 'listTableIndexes() has to return a "primary" array key.');
         self::assertEquals(['id', 'other_id'], array_map('strtolower', $tableIndexes['primary']->getColumns()));
@@ -498,10 +532,6 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
     public function testCreateTableWithForeignKeys(): void
     {
-        if (! $this->schemaManager->getDatabasePlatform()->supportsForeignKeyConstraints()) {
-            self::markTestSkipped('Platform does not support foreign keys.');
-        }
-
         $tableB = $this->getTestTable('test_foreign');
 
         $this->dropAndCreateTable($tableB);
@@ -513,7 +543,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
         $fkTable       = $this->schemaManager->listTableDetails('test_create_fk');
         $fkConstraints = $fkTable->getForeignKeys();
-        self::assertEquals(1, count($fkConstraints), "Table 'test_create_fk1' has to have one foreign key.");
+        self::assertCount(1, $fkConstraints, "Table 'test_create_fk' has to have one foreign key.");
 
         $fkConstraint = current($fkConstraints);
         self::assertInstanceOf(ForeignKeyConstraint::class, $fkConstraint);
@@ -526,10 +556,6 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
     public function testListForeignKeys(): void
     {
-        if (! $this->connection->getDatabasePlatform()->supportsForeignKeyConstraints()) {
-            self::markTestSkipped('Does not support foreign key constraints.');
-        }
-
         $this->createTestTable('test_create_fk1');
         $this->createTestTable('test_create_fk2');
 
@@ -545,7 +571,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
         $fkeys = $this->schemaManager->listTableForeignKeys('test_create_fk1');
 
-        self::assertEquals(1, count($fkeys), "Table 'test_create_fk1' has to have one foreign key.");
+        self::assertCount(1, $fkeys, "Table 'test_create_fk1' has to have one foreign key.");
 
         self::assertInstanceOf(ForeignKeyConstraint::class, $fkeys[0]);
         self::assertEquals(['foreign_key_test'], array_map('strtolower', $fkeys[0]->getLocalColumns()));
@@ -559,6 +585,32 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         self::assertEquals('CASCADE', $fkeys[0]->getOption('onDelete'));
     }
 
+    public function testCreateForeignKeyWithTableObject(): void
+    {
+        $this->createTestTable('test_create_fk1');
+        $this->createTestTable('test_create_fk2');
+
+        $table = $this->schemaManager->listTableDetails('test_create_fk1');
+        $table->addForeignKeyConstraint(
+            'test_create_fk2',
+            ['foreign_key_test'],
+            ['id'],
+            [],
+            'i'
+        );
+        $foreignKey = $table->getForeignKeys()['i'];
+        $this->schemaManager->createForeignKey($foreignKey, $table);
+
+        $fkeys = $this->schemaManager->listTableForeignKeys('test_create_fk1');
+
+        self::assertCount(1, $fkeys, "Table 'test_create_fk1' has to have one foreign key.");
+
+        self::assertInstanceOf(ForeignKeyConstraint::class, $fkeys[0]);
+        self::assertEquals(['foreign_key_test'], array_map('strtolower', $fkeys[0]->getLocalColumns()));
+        self::assertEquals(['id'], array_map('strtolower', $fkeys[0]->getForeignColumns()));
+        self::assertEquals('test_create_fk2', strtolower($fkeys[0]->getForeignTableName()));
+    }
+
     protected function getCreateExampleViewSql(): void
     {
         self::markTestSkipped('No Create Example View SQL was defined for this SchemaManager');
@@ -602,7 +654,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
     public function testAlterTableScenario(): void
     {
-        if (! $this->schemaManager->getDatabasePlatform()->supportsAlterTable()) {
+        if (! $this->connection->getDatabasePlatform()->supportsAlterTable()) {
             self::markTestSkipped('Alter Table is not supported by this platform.');
         }
 
@@ -613,8 +665,8 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         self::assertTrue($table->hasColumn('id'));
         self::assertTrue($table->hasColumn('test'));
         self::assertTrue($table->hasColumn('foreign_key_test'));
-        self::assertEquals(0, count($table->getForeignKeys()));
-        self::assertEquals(1, count($table->getIndexes()));
+        self::assertCount(0, $table->getForeignKeys());
+        self::assertCount(1, $table->getIndexes());
 
         $tableDiff                         = new TableDiff('alter_table');
         $tableDiff->fromTable              = $alterTable;
@@ -634,7 +686,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         $this->schemaManager->alterTable($tableDiff);
 
         $table = $this->schemaManager->listTableDetails('alter_table');
-        self::assertEquals(2, count($table->getIndexes()));
+        self::assertCount(2, $table->getIndexes());
         self::assertTrue($table->hasIndex('foo_idx'));
         self::assertEquals(['foo'], array_map('strtolower', $table->getIndex('foo_idx')->getColumns()));
         self::assertFalse($table->getIndex('foo_idx')->isPrimary());
@@ -647,7 +699,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         $this->schemaManager->alterTable($tableDiff);
 
         $table = $this->schemaManager->listTableDetails('alter_table');
-        self::assertEquals(2, count($table->getIndexes()));
+        self::assertCount(2, $table->getIndexes());
         self::assertTrue($table->hasIndex('foo_idx'));
         self::assertEquals(
             ['foo', 'foreign_key_test'],
@@ -661,7 +713,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         $this->schemaManager->alterTable($tableDiff);
 
         $table = $this->schemaManager->listTableDetails('alter_table');
-        self::assertEquals(2, count($table->getIndexes()));
+        self::assertCount(2, $table->getIndexes());
         self::assertTrue($table->hasIndex('bar_idx'));
         self::assertFalse($table->hasIndex('foo_idx'));
         self::assertEquals(
@@ -683,10 +735,6 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         // dont check for index size here, some platforms automatically add indexes for foreign keys.
         self::assertFalse($table->hasIndex('bar_idx'));
 
-        if (! $this->schemaManager->getDatabasePlatform()->supportsForeignKeyConstraints()) {
-            return;
-        }
-
         $fks = $table->getForeignKeys();
         self::assertCount(1, $fks);
         $foreignKey = current($fks);
@@ -697,7 +745,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
     public function testTableInNamespace(): void
     {
-        if (! $this->schemaManager->getDatabasePlatform()->supportsSchemas()) {
+        if (! $this->connection->getDatabasePlatform()->supportsSchemas()) {
             self::markTestSkipped('Schema definition is not supported by this platform.');
         }
 
@@ -705,7 +753,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         $diff                  = new SchemaDiff();
         $diff->newNamespaces[] = 'testschema';
 
-        foreach ($diff->toSql($this->schemaManager->getDatabasePlatform()) as $sql) {
+        foreach ($diff->toSql($this->connection->getDatabasePlatform()) as $sql) {
             $this->connection->executeStatement($sql);
         }
 
@@ -721,7 +769,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
     public function testCreateAndListViews(): void
     {
-        if (! $this->schemaManager->getDatabasePlatform()->supportsViews()) {
+        if (! $this->connection->getDatabasePlatform()->supportsViews()) {
             self::markTestSkipped('Views is not supported by this platform.');
         }
 
@@ -745,7 +793,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
     public function testAutoincrementDetection(): void
     {
-        if (! $this->schemaManager->getDatabasePlatform()->supportsIdentityColumns()) {
+        if (! $this->connection->getDatabasePlatform()->supportsIdentityColumns()) {
             self::markTestSkipped('This test is only supported on platforms that have autoincrement');
         }
 
@@ -763,7 +811,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
     public function testAutoincrementDetectionMulticolumns(): void
     {
-        if (! $this->schemaManager->getDatabasePlatform()->supportsIdentityColumns()) {
+        if (! $this->connection->getDatabasePlatform()->supportsIdentityColumns()) {
             self::markTestSkipped('This test is only supported on platforms that have autoincrement');
         }
 
@@ -787,12 +835,6 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
      */
     public function testUpdateSchemaWithForeignKeyRenaming(callable $comparatorFactory): void
     {
-        $platform = $this->schemaManager->getDatabasePlatform();
-
-        if (! $platform->supportsForeignKeyConstraints()) {
-            self::markTestSkipped('This test is only supported on platforms that have foreign keys.');
-        }
-
         $table = new Table('test_fk_base');
         $table->addColumn('id', 'integer');
         $table->setPrimaryKey(['id']);
@@ -839,12 +881,6 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
      */
     public function testRenameIndexUsedInForeignKeyConstraint(callable $comparatorFactory): void
     {
-        $platform = $this->schemaManager->getDatabasePlatform();
-
-        if (! $platform->supportsForeignKeyConstraints()) {
-            self::markTestSkipped('This test is only supported on platforms that have foreign keys.');
-        }
-
         $primaryTable = new Table('test_rename_index_primary');
         $primaryTable->addColumn('id', 'integer');
         $primaryTable->setPrimaryKey(['id']);
@@ -900,7 +936,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         $this->schemaManager->createTable($table);
 
         $columns = $this->schemaManager->listTableColumns('column_comment_test');
-        self::assertEquals(1, count($columns));
+        self::assertCount(1, $columns);
         self::assertEquals('This is a comment', $columns['id']->getComment());
 
         $tableDiff                       = new TableDiff('column_comment_test');
@@ -922,7 +958,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         $this->schemaManager->alterTable($tableDiff);
 
         $columns = $this->schemaManager->listTableColumns('column_comment_test');
-        self::assertEquals(1, count($columns));
+        self::assertCount(1, $columns);
         self::assertEmpty($columns['id']->getComment());
     }
 
@@ -947,7 +983,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         $this->schemaManager->createTable($table);
 
         $columns = $this->schemaManager->listTableColumns('column_comment_test2');
-        self::assertEquals(3, count($columns));
+        self::assertCount(3, $columns);
         self::assertEquals('This is a comment', $columns['id']->getComment());
         self::assertEquals('This is a comment', $columns['obj']->getComment());
         self::assertInstanceOf(ObjectType::class, $columns['obj']->getType());
@@ -975,7 +1011,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         $this->schemaManager->createTable($table);
 
         $columns = $this->schemaManager->listTableColumns('column_dateinterval_comment');
-        self::assertEquals(2, count($columns));
+        self::assertCount(2, $columns);
         self::assertEquals('This is a comment', $columns['id']->getComment());
         self::assertEquals('This is a comment', $columns['date_interval']->getComment());
         self::assertInstanceOf(DateIntervalType::class, $columns['date_interval']->getType());
@@ -1092,10 +1128,6 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
     public function testListForeignKeysComposite(): void
     {
-        if (! $this->connection->getDatabasePlatform()->supportsForeignKeyConstraints()) {
-            self::markTestSkipped('Does not support foreign key constraints.');
-        }
-
         $this->schemaManager->createTable($this->getTestTable('test_create_fk3'));
         $this->schemaManager->createTable($this->getTestCompositeTable('test_create_fk4'));
 
@@ -1110,7 +1142,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
         $fkeys = $this->schemaManager->listTableForeignKeys('test_create_fk3');
 
-        self::assertEquals(1, count($fkeys), "Table 'test_create_fk3' has to have one foreign key.");
+        self::assertCount(1, $fkeys, "Table 'test_create_fk3' has to have one foreign key.");
 
         self::assertInstanceOf(ForeignKeyConstraint::class, $fkeys[0]);
         self::assertEquals(['id', 'foreign_key_test'], array_map('strtolower', $fkeys[0]->getLocalColumns()));
@@ -1207,11 +1239,11 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
     public function testListTableDetailsWithFullQualifiedTableName(): void
     {
-        if (! $this->schemaManager->getDatabasePlatform()->supportsSchemas()) {
+        if (! $this->connection->getDatabasePlatform()->supportsSchemas()) {
             self::markTestSkipped('Test only works on platforms that support schemas.');
         }
 
-        $defaultSchemaName = $this->schemaManager->getDatabasePlatform()->getDefaultSchemaName();
+        $defaultSchemaName = $this->connection->getDatabasePlatform()->getDefaultSchemaName();
         $primaryTableName  = 'primary_table';
         $foreignTableName  = 'foreign_table';
 
@@ -1313,7 +1345,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         ?string $comment2,
         ?string $expectedComment2
     ): void {
-        $platform = $this->schemaManager->getDatabasePlatform();
+        $platform = $this->connection->getDatabasePlatform();
 
         if (
             ! $platform->supportsInlineColumnComments() &&
@@ -1385,10 +1417,6 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
     public function testDoesNotListIndexesImplicitlyCreatedByForeignKeys(): void
     {
-        if (! $this->schemaManager->getDatabasePlatform()->supportsForeignKeyConstraints()) {
-            self::markTestSkipped('This test is only supported on platforms that have foreign keys.');
-        }
-
         $primaryTable = new Table('test_list_index_impl_primary');
         $primaryTable->addColumn('id', 'integer');
         $primaryTable->setPrimaryKey(['id']);
@@ -1417,7 +1445,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
      */
     public function testComparatorShouldNotAddCommentToJsonTypeSinceItIsTheDefaultNow(callable $comparatorFactory): void
     {
-        $platform = $this->schemaManager->getDatabasePlatform();
+        $platform = $this->connection->getDatabasePlatform();
 
         if (! $platform->hasNativeJsonType()) {
             self::markTestSkipped('This test is only supported on platforms that have native JSON type.');
@@ -1464,7 +1492,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
     public function testCreateAndListSequences(): void
     {
-        if (! $this->schemaManager->getDatabasePlatform()->supportsSequences()) {
+        if (! $this->connection->getDatabasePlatform()->supportsSequences()) {
             self::markTestSkipped('This test is only supported on platforms that support sequences.');
         }
 
@@ -1505,7 +1533,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
      */
     public function testComparisonWithAutoDetectedSequenceDefinition(callable $comparatorFactory): void
     {
-        $platform = $this->schemaManager->getDatabasePlatform();
+        $platform = $this->connection->getDatabasePlatform();
 
         if (! $platform->supportsSequences()) {
             self::markTestSkipped('This test is only supported on platforms that support sequences.');
@@ -1566,7 +1594,7 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
     public function testGenerateAnIndexWithPartialColumnLength(): void
     {
-        if (! $this->schemaManager->getDatabasePlatform()->supportsColumnLengthIndexes()) {
+        if (! $this->connection->getDatabasePlatform()->supportsColumnLengthIndexes()) {
             self::markTestSkipped(
                 'This test is only supported on platforms that support indexes with column length definitions.'
             );
@@ -1599,10 +1627,6 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
 
     public function testCreatedCompositeForeignKeyOrderIsCorrectAfterCreation(): void
     {
-        if (! $this->schemaManager->getDatabasePlatform()->supportsForeignKeyConstraints()) {
-            self::markTestSkipped('Platform does not support foreign keys.');
-        }
-
         $foreignKey     = 'fk_test_order';
         $localTable     = 'test_table_foreign';
         $foreignTable   = 'test_table_local';
@@ -1644,6 +1668,66 @@ abstract class SchemaManagerFunctionalTestCase extends FunctionalTestCase
         self::assertSame($localColumns, array_map('strtolower', $foreignKey->getLocalColumns()));
         self::assertSame($foreignColumns, array_map('strtolower', $foreignKey->getForeignColumns()));
     }
+
+    public function testIntrospectReservedKeywordTableViaListTableDetails(): void
+    {
+        $this->createReservedKeywordTables();
+
+        $user = $this->schemaManager->listTableDetails('"user"');
+        self::assertCount(2, $user->getColumns());
+        self::assertCount(2, $user->getIndexes());
+        self::assertCount(1, $user->getForeignKeys());
+    }
+
+    public function testIntrospectReservedKeywordTableViaListTables(): void
+    {
+        $this->createReservedKeywordTables();
+
+        $tables = $this->schemaManager->listTables();
+
+        $user = $this->findTableByName($tables, 'user');
+        self::assertNotNull($user);
+        self::assertCount(2, $user->getColumns());
+        self::assertCount(2, $user->getIndexes());
+        self::assertCount(1, $user->getForeignKeys());
+    }
+
+    private function createReservedKeywordTables(): void
+    {
+        $platform = $this->connection->getDatabasePlatform();
+
+        $this->dropTableIfExists($platform->quoteIdentifier('user'));
+        $this->dropTableIfExists($platform->quoteIdentifier('group'));
+
+        $schema = new Schema();
+
+        $user = $schema->createTable('user');
+        $user->addColumn('id', 'integer');
+        $user->addColumn('group_id', 'integer');
+        $user->setPrimaryKey(['id']);
+        $user->addForeignKeyConstraint('group', ['group_id'], ['id']);
+
+        $group = $schema->createTable('group');
+        $group->addColumn('id', 'integer');
+        $group->setPrimaryKey(['id']);
+
+        $schemaManager = $this->connection->createSchemaManager();
+        $schemaManager->createSchemaObjects($schema);
+    }
+
+    /**
+     * @param list<Table> $tables
+     */
+    protected function findTableByName(array $tables, string $name): ?Table
+    {
+        foreach ($tables as $table) {
+            if (strtolower($table->getName()) === $name) {
+                return $table;
+            }
+        }
+
+        return null;
+    }
 }
 
 interface ListTableColumnsDispatchEventListener
