@@ -2,7 +2,6 @@
 
 namespace Doctrine\DBAL\Tests\Functional\Ticket;
 
-use Doctrine\DBAL\Platforms\PostgreSQLPlatform;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
 
@@ -10,10 +9,6 @@ class DBAL168Test extends FunctionalTestCase
 {
     public function testDomainsTable(): void
     {
-        if ($this->connection->getDatabasePlatform() instanceof PostgreSQLPlatform) {
-            self::markTestSkipped('PostgreSQL only test');
-        }
-
         $table = new Table('domains');
         $table->addColumn('id', 'integer');
         $table->addColumn('parent_id', 'integer');
