@@ -34,10 +34,9 @@ use function str_repeat;
 abstract class AbstractPlatformTestCase extends TestCase
 {
     /** @var T */
-    protected $platform;
+    protected AbstractPlatform $platform;
 
-    /** @var Type|null */
-    private $backedUpType;
+    private ?Type $backedUpType = null;
 
     /**
      * @return T
@@ -273,18 +272,6 @@ abstract class AbstractPlatformTestCase extends TestCase
         self::assertEquals($this->getGenerateConstraintForeignKeySql($fk), $sql);
     }
 
-    public function testGeneratesForeignKeySqlOnlyWhenSupportingForeignKeys(): void
-    {
-        $fk = new ForeignKeyConstraint(['fk_name'], 'foreign', ['id'], 'constraint_fk');
-
-        if ($this->platform->supportsForeignKeyConstraints()) {
-            self::assertIsString($this->platform->getCreateForeignKeySQL($fk, 'test'));
-        } else {
-            $this->expectException(Exception::class);
-            $this->platform->getCreateForeignKeySQL($fk, 'test');
-        }
-    }
-
     protected function getBitAndComparisonExpressionSql(string $value1, string $value2): string
     {
         return '(' . $value1 . ' & ' . $value2 . ')';
@@ -717,7 +704,10 @@ abstract class AbstractPlatformTestCase extends TestCase
             'FK_WITH_INTENDED_QUOTATION'
         );
 
-        $sql = $this->platform->getCreateTableSQL($table, AbstractPlatform::CREATE_FOREIGNKEYS);
+        $sql = $this->platform->getCreateTableSQL(
+            $table,
+            AbstractPlatform::CREATE_INDEXES | AbstractPlatform::CREATE_FOREIGNKEYS
+        );
         self::assertEquals($this->getQuotedColumnInForeignKeySQL(), $sql);
     }
 
@@ -1084,12 +1074,6 @@ abstract class AbstractPlatformTestCase extends TestCase
 
     public function testQuotesDropForeignKeySQL(): void
     {
-        if (! $this->platform->supportsForeignKeyConstraints()) {
-            $this->markTestSkipped(
-                sprintf('%s does not support foreign key constraints.', get_class($this->platform))
-            );
-        }
-
         $tableName      = 'table';
         $table          = new Table($tableName);
         $foreignKeyName = 'select';
