@@ -186,17 +186,17 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     {
         self::assertEquals(
             'CHAR(10)',
-            $this->platform->getVarcharTypeDeclarationSQL(
+            $this->platform->getStringTypeDeclarationSQL(
                 ['length' => 10, 'fixed' => true]
             )
         );
         self::assertEquals(
             'VARCHAR2(50)',
-            $this->platform->getVarcharTypeDeclarationSQL(['length' => 50])
+            $this->platform->getStringTypeDeclarationSQL(['length' => 50])
         );
         self::assertEquals(
             'VARCHAR2(255)',
-            $this->platform->getVarcharTypeDeclarationSQL([])
+            $this->platform->getStringTypeDeclarationSQL([])
         );
     }
 
@@ -485,6 +485,7 @@ SQL
                 . ' REFERENCES foo ("create", bar, "foo-bar")',
             'ALTER TABLE "quoted" ADD CONSTRAINT FK_WITH_INTENDED_QUOTATION FOREIGN KEY ("create", foo, "bar")'
                 . ' REFERENCES "foo-bar" ("create", bar, "foo-bar")',
+            'CREATE INDEX IDX_22660D028FD6E0FB8C736521D79164E3 ON "quoted" ("create", foo, "bar")',
         ];
     }
 
