@@ -139,17 +139,17 @@ class SQLServerPlatformTestCase extends AbstractPlatformTestCase
     {
         self::assertEquals(
             'NCHAR(10)',
-            $this->platform->getVarcharTypeDeclarationSQL(
+            $this->platform->getStringTypeDeclarationSQL(
                 ['length' => 10, 'fixed' => true]
             )
         );
         self::assertEquals(
             'NVARCHAR(50)',
-            $this->platform->getVarcharTypeDeclarationSQL(['length' => 50])
+            $this->platform->getStringTypeDeclarationSQL(['length' => 50])
         );
         self::assertEquals(
             'NVARCHAR(255)',
-            $this->platform->getVarcharTypeDeclarationSQL([])
+            $this->platform->getStringTypeDeclarationSQL([])
         );
         self::assertSame('VARCHAR(MAX)', $this->platform->getClobTypeDeclarationSQL([]));
         self::assertSame(
