@@ -2,6 +2,7 @@
 
 namespace Doctrine\DBAL\Tests\Query;
 
+use Doctrine\DBAL\Cache\QueryCacheProfile;
 use Doctrine\DBAL\Connection;
 use Doctrine\DBAL\ParameterType;
 use Doctrine\DBAL\Query\Expression\ExpressionBuilder;
@@ -16,7 +17,7 @@ use PHPUnit\Framework\TestCase;
 class QueryBuilderTest extends TestCase
 {
     /** @var Connection&MockObject */
-    protected $conn;
+    protected Connection $conn;
 
     protected function setUp(): void
     {
@@ -882,16 +883,16 @@ class QueryBuilderTest extends TestCase
 
         $qb->select('*')->from('users');
 
-        self::assertNull($qb->getParameterType('name'));
+        self::assertSame(ParameterType::STRING, $qb->getParameterType('name'));
 
         $qb->where('name = :name');
         $qb->setParameter('name', 'foo');
 
-        self::assertNull($qb->getParameterType('name'));
-
-        $qb->setParameter('name', 'foo', ParameterType::STRING);
-
         self::assertSame(ParameterType::STRING, $qb->getParameterType('name'));
+
+        $qb->setParameter('name', 'foo', ParameterType::INTEGER);
+
+        self::assertSame(ParameterType::INTEGER, $qb->getParameterType('name'));
     }
 
     public function testGetParameterTypes(): void
@@ -905,9 +906,9 @@ class QueryBuilderTest extends TestCase
         $qb->where('name = :name');
         $qb->setParameter('name', 'foo');
 
-        self::assertSame([], $qb->getParameterTypes());
-
-        $qb->setParameter('name', 'foo', ParameterType::STRING);
+        self::assertSame([
+            'name' => ParameterType::STRING,
+        ], $qb->getParameterTypes());
 
         $qb->where('is_active = :isActive');
         $qb->setParameter('isActive', true, ParameterType::BOOLEAN);
@@ -965,11 +966,16 @@ class QueryBuilderTest extends TestCase
         array $parameterTypes,
         string $expectedSql
     ): void {
-        $qb = new QueryBuilder($this->conn);
+        $qb           = new QueryBuilder($this->conn);
+        $mockedResult = $this->createMock(Result::class);
 
         $this->conn->expects(self::once())
+            ->method('executeQuery')
+            ->with($expectedSql, $parameters, $parameterTypes, null)
+            ->willReturn($mockedResult);
+
+        $mockedResult->expects(self::once())
             ->method('fetchAssociative')
-            ->with($expectedSql, $parameters, $parameterTypes)
             ->willReturn(['username' => 'jwage', 'password' => 'changeme']);
 
         $row = $qb->select($select)
@@ -995,11 +1001,16 @@ class QueryBuilderTest extends TestCase
         array $parameterTypes,
         string $expectedSql
     ): void {
-        $qb = new QueryBuilder($this->conn);
+        $qb           = new QueryBuilder($this->conn);
+        $mockedResult = $this->createMock(Result::class);
 
         $this->conn->expects(self::once())
+            ->method('executeQuery')
+            ->with($expectedSql, $parameters, $parameterTypes, null)
+            ->willReturn($mockedResult);
+
+        $mockedResult->expects(self::once())
             ->method('fetchNumeric')
-            ->with($expectedSql, $parameters, $parameterTypes)
             ->willReturn(['jwage', 'changeme']);
 
         $row = $qb->select($select)
@@ -1025,11 +1036,16 @@ class QueryBuilderTest extends TestCase
         array $parameterTypes,
         string $expectedSql
     ): void {
-        $qb = new QueryBuilder($this->conn);
+        $qb           = new QueryBuilder($this->conn);
+        $mockedResult = $this->createMock(Result::class);
 
         $this->conn->expects(self::once())
+            ->method('executeQuery')
+            ->with($expectedSql, $parameters, $parameterTypes, null)
+            ->willReturn($mockedResult);
+
+        $mockedResult->expects(self::once())
             ->method('fetchOne')
-            ->with($expectedSql, $parameters, $parameterTypes)
             ->willReturn('jwage');
 
         $username = $qb->select($select)
@@ -1055,11 +1071,16 @@ class QueryBuilderTest extends TestCase
         array $parameterTypes,
         string $expectedSql
     ): void {
-        $qb = new QueryBuilder($this->conn);
+        $qb           = new QueryBuilder($this->conn);
+        $mockedResult = $this->createMock(Result::class);
 
         $this->conn->expects(self::once())
+            ->method('executeQuery')
+            ->with($expectedSql, $parameters, $parameterTypes, null)
+            ->willReturn($mockedResult);
+
+        $mockedResult->expects(self::once())
             ->method('fetchAllAssociative')
-            ->with($expectedSql, $parameters, $parameterTypes)
             ->willReturn(
                 [
                     ['username' => 'jwage', 'password' => 'changeme'],
@@ -1096,11 +1117,16 @@ class QueryBuilderTest extends TestCase
         array $parameterTypes,
         string $expectedSql
     ): void {
-        $qb = new QueryBuilder($this->conn);
+        $qb           = new QueryBuilder($this->conn);
+        $mockedResult = $this->createMock(Result::class);
 
         $this->conn->expects(self::once())
+            ->method('executeQuery')
+            ->with($expectedSql, $parameters, $parameterTypes, null)
+            ->willReturn($mockedResult);
+
+        $mockedResult->expects(self::once())
             ->method('fetchAllNumeric')
-            ->with($expectedSql, $parameters, $parameterTypes)
             ->willReturn(
                 [
                     ['jwage', 'changeme'],
@@ -1137,11 +1163,16 @@ class QueryBuilderTest extends TestCase
         array $parameterTypes,
         string $expectedSql
     ): void {
-        $qb = new QueryBuilder($this->conn);
+        $qb           = new QueryBuilder($this->conn);
+        $mockedResult = $this->createMock(Result::class);
 
         $this->conn->expects(self::once())
+            ->method('executeQuery')
+            ->with($expectedSql, $parameters, $parameterTypes, null)
+            ->willReturn($mockedResult);
+
+        $mockedResult->expects(self::once())
             ->method('fetchAllKeyValue')
-            ->with($expectedSql, $parameters, $parameterTypes)
             ->willReturn(
                 [
                     'jwage' => 'changeme',
@@ -1178,11 +1209,16 @@ class QueryBuilderTest extends TestCase
         array $parameterTypes,
         string $expectedSql
     ): void {
-        $qb = new QueryBuilder($this->conn);
+        $qb           = new QueryBuilder($this->conn);
+        $mockedResult = $this->createMock(Result::class);
 
         $this->conn->expects(self::once())
+            ->method('executeQuery')
+            ->with($expectedSql, $parameters, $parameterTypes, null)
+            ->willReturn($mockedResult);
+
+        $mockedResult->expects(self::once())
             ->method('fetchAllAssociativeIndexed')
-            ->with($expectedSql, $parameters, $parameterTypes)
             ->willReturn(
                 [
                     1 => [
@@ -1223,11 +1259,16 @@ class QueryBuilderTest extends TestCase
         array $parameterTypes,
         string $expectedSql
     ): void {
-        $qb = new QueryBuilder($this->conn);
+        $qb           = new QueryBuilder($this->conn);
+        $mockedResult = $this->createMock(Result::class);
 
         $this->conn->expects(self::once())
+            ->method('executeQuery')
+            ->with($expectedSql, $parameters, $parameterTypes, null)
+            ->willReturn($mockedResult);
+
+        $mockedResult->expects(self::once())
             ->method('fetchFirstColumn')
-            ->with($expectedSql, $parameters, $parameterTypes)
             ->willReturn(
                 [
                     'jwage',
@@ -1320,7 +1361,7 @@ class QueryBuilderTest extends TestCase
 
         $this->conn->expects(self::once())
             ->method('executeQuery')
-            ->with($expectedSql, $parameters, $parameterTypes)
+            ->with($expectedSql, $parameters, $parameterTypes, null)
             ->willReturn($mockedResult);
 
         $results = $qb->select($select)
@@ -1335,6 +1376,42 @@ class QueryBuilderTest extends TestCase
         );
     }
 
+    /**
+     * @param list<mixed>|array<string, mixed>                                     $parameters
+     * @param array<int, int|string|Type|null>|array<string, int|string|Type|null> $parameterTypes
+     *
+     * @dataProvider fetchProvider
+     */
+    public function testExecuteQueryWithResultCaching(
+        string $select,
+        string $from,
+        string $where,
+        array $parameters,
+        array $parameterTypes,
+        string $expectedSql
+    ): void {
+        $qb           = new QueryBuilder($this->conn);
+        $qcp          = new QueryCacheProfile(300);
+        $mockedResult = $this->createMock(Result::class);
+
+        $this->conn->expects(self::once())
+            ->method('executeQuery')
+            ->with($expectedSql, $parameters, $parameterTypes, $qcp)
+            ->willReturn($mockedResult);
+
+        $results = $qb->select($select)
+            ->from($from)
+            ->where($where)
+            ->setParameters($parameters, $parameterTypes)
+            ->enableResultCache($qcp)
+            ->executeQuery();
+
+        self::assertSame(
+            $mockedResult,
+            $results
+        );
+    }
+
     public function testExecuteStatement(): void
     {
         $qb           = new QueryBuilder($this->conn);
